@@ -12,8 +12,7 @@ from django.conf import settings
 from django.shortcuts import redirect
 from rest_framework import response
 
-from revpayment.exceptions import (HttpActionError, InvalidCallback,
-                                   PaymentException)
+from revpayment.exceptions import HttpActionError, InvalidCallback, PaymentException
 from revpayment.settings import api_settings
 
 SNS_MESSAGE_TYPE_SUB_NOTIFICATION = "SubscriptionConfirmation"
@@ -164,7 +163,7 @@ def verify_sns_notification(request):
             PKCS1v15(),
             hashes.SHA1(),
         )
-g        return True
+        return True
     except InvalidSignature:
         raise InvalidCallback()
 
