@@ -1,15 +1,6 @@
 import copy
-import json
-from datetime import datetime
-
-import requests
-from django.conf import settings
-from django.http import HttpResponse
-from django.shortcuts import redirect
-from django.utils import timezone
 
 from revpayment import actions
-from revpayment.logistics import LogisticsSDK
 from revpayment.settings import api_settings
 
 
