@@ -1,14 +1,12 @@
 import json
 
 from django.contrib.auth.models import User
-from rest_framework import exceptions, parsers, permissions, response, views, viewsets
+from rest_framework import (exceptions, parsers, permissions, response, views,
+                            viewsets)
 from rest_framework.decorators import action
 
-from revpayment.checkout import (
-    verify_sns_notification,
-    SNS_MESSAGE_TYPE_SUB_NOTIFICATION,
-    confirm_subcription,
-)
+from revpayment.checkout import (SNS_MESSAGE_TYPE_SUB_NOTIFICATION,
+                                 confirm_subcription, verify_sns_notification)
 from revpayment.models import RedirectState
 from revpayment.settings import api_settings
 
